@@ -8,7 +8,7 @@ use crate::watcher;
 use futures::{Stream, TryStreamExt};
 use kube_client::Resource;
 use std::hash::Hash;
-pub use store::Store;
+pub use store::{store, Store};
 
 /// Caches objects from `watcher::Event`s to a local `Store`
 ///
@@ -16,13 +16,13 @@ pub use store::Store;
 ///
 /// Note: It is a bad idea to feed a single `reflector` from multiple `watcher`s, since
 /// the whole `Store` will be cleared whenever any of them emits a `Restarted` event.
-pub fn reflector<K, W>(mut store: store::Writer<K>, stream: W) -> impl Stream<Item = W::Item>
+pub fn reflector<K, W>(mut writer: store::Writer<K>, stream: W) -> impl Stream<Item = W::Item>
 where
     K: Resource + Clone,
     K::DynamicType: Eq + Hash + Clone,
     W: Stream<Item = watcher::Result<watcher::Event<K>>>,
 {
-    stream.inspect_ok(move |event| store.apply_watcher_event(event))
+    stream.inspect_ok(move |event| writer.apply_watcher_event(event))
 }
 
 #[cfg(test)]
